==> ponyc-0.21.3-2-x86_64.pkg.tar.xz: usr/share/doc/pony/stdlib-docs/docs/cli-_StringSeq.md <==
# _StringSeq

_StringSeq is a wrapper / helper class for working with String sequence
values while parsing. It assists in collecting the strings as they are
parsed, and producing a ReadSeq[String] as a result.


```pony
class ref _StringSeq is
  ReadSeq[String val] box
```

#### Implements

* [ReadSeq](builtin-ReadSeq)\[[String](builtin-String) val\] box

---

## Constructors

### empty

```pony
new val empty()
: _StringSeq val^
```

#### Returns

* [_StringSeq](cli-_StringSeq) val^

---

### from_string

```pony
new val from_string(
  s: String val)
: _StringSeq val^
```
#### Parameters

*   s: [String](builtin-String) val

#### Returns

* [_StringSeq](cli-_StringSeq) val^

---

### from_concat

```pony
new val from_concat(
  ss0: _StringSeq val,
  ss1: _StringSeq val)
: _StringSeq val^
```
#### Parameters

*   ss0: [_StringSeq](cli-_StringSeq) val
*   ss1: [_StringSeq](cli-_StringSeq) val

#### Returns

* [_StringSeq](cli-_StringSeq) val^

---

## Public fields

* let strings: [Vec](collections-persistent-Vec)\[[String](builtin-String) val\] val

---

## Public Functions

### string

```pony
fun box string()
: String iso^
```

#### Returns

* [String](builtin-String) iso^

---

### size

```pony
fun box size()
: USize val
```

#### Returns

* [USize](builtin-USize) val

---

### apply

```pony
fun box apply(
  i: USize val)
: String val ?
```
#### Parameters

*   i: [USize](builtin-USize) val

#### Returns

* [String](builtin-String) val ?

---

### values

```pony
fun box values()
: Iterator[String val] ref^
```

#### Returns

* [Iterator](builtin-Iterator)\[[String](builtin-String) val\] ref^

---

==> ponyc-0.22.3-1-x86_64.pkg.tar.xz: usr/share/doc/pony/stdlib-docs/docs/cli-_StringSeq.md <==
# _StringSeq
<span class="source-link">[[Source]](src/cli/command_spec.md#L470)</span>

_StringSeq is a wrapper / helper class for working with String sequence
values while parsing. It assists in collecting the strings as they are
parsed, and producing a ReadSeq[String] as a result.


```pony
class ref _StringSeq is
  ReadSeq[String val] box
```

#### Implements

* [ReadSeq](builtin-ReadSeq)\[[String](builtin-String) val\] box

---

## Constructors

### empty
<span class="source-link">[[Source]](src/cli/command_spec.md#L478)</span>


```pony
new val empty()
: _StringSeq val^
```

#### Returns

* [_StringSeq](cli-_StringSeq) val^

---

### from_string
<span class="source-link">[[Source]](src/cli/command_spec.md#L481)</span>


```pony
new val from_string(
  s: String val)
: _StringSeq val^
```
#### Parameters

*   s: [String](builtin-String) val

#### Returns

* [_StringSeq](cli-_StringSeq) val^

---

### from_concat
<span class="source-link">[[Source]](src/cli/command_spec.md#L484)</span>


```pony
new val from_concat(
  ss0: _StringSeq val,
  ss1: _StringSeq val)
: _StringSeq val^
```
#### Parameters

*   ss0: [_StringSeq](cli-_StringSeq) val
*   ss1: [_StringSeq](cli-_StringSeq) val

#### Returns

* [_StringSeq](cli-_StringSeq) val^

---

## Public fields

### let strings: [Vec](collections-persistent-Vec)\[[String](builtin-String) val\] val
<span class="source-link">[[Source]](src/cli/command_spec.md#L476)</span>



---

## Public Functions

### string
<span class="source-link">[[Source]](src/cli/command_spec.md#L487)</span>


```pony
fun box string()
: String iso^
```

#### Returns

* [String](builtin-String) iso^

---

### size
<span class="source-link">[[Source]](src/cli/command_spec.md#L497)</span>


```pony
fun box size()
: USize val
```

#### Returns

* [USize](builtin-USize) val

---

### apply
<span class="source-link">[[Source]](src/cli/command_spec.md#L498)</span>


```pony
fun box apply(
  i: USize val)
: String val ?
```
#### Parameters

*   i: [USize](builtin-USize) val

#### Returns

* [String](builtin-String) val ?

---

### values
<span class="source-link">[[Source]](src/cli/command_spec.md#L499)</span>


```pony
fun box values()
: Iterator[String val] ref^
```

#### Returns

* [Iterator](builtin-Iterator)\[[String](builtin-String) val\] ref^

---
